==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Tux/Resources/translations/Tux_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>选择</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>缩放</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>旋转</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>平移</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>倾斜</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>导航样式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>向上翻页 或 向下翻页 键。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>回转中心</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or key H.</source>
      <translation>鼠标中键或H键</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>鼠标中键</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>无法识别导航样式。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>设置</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>导航模式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>压缩</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>工具提示</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>转盘</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>轨迹球</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation type="unfinished">Undefined</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Tux/Resources/translations/Tux_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>选择</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>缩放</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>旋转</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>平移</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>倾斜</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>导航样式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>向上翻页 或 向下翻页 键。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>回转中心</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or key H.</source>
      <translation>鼠标中键或H键</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>鼠标中键</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>无法识别导航样式。</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>设置</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>环绕模式</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>压缩</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>工具提示</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>转盘</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>轨迹球</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation type="unfinished">Undefined</translation>
    </message>
  </context>
</TS>
